Struct zng_ext_undo::UndoTransaction
source · pub struct UndoTransaction { /* private fields */ }Expand description
Represents captured undo actions in an UNDO.transaction operation.
Implementations
sourceimpl UndoTransaction
impl UndoTransaction
sourcepub fn commit(self)
pub fn commit(self)
Push all undo actions captured by the transaction into the current undo scope.
sourcepub fn commit_group(self, info: impl UndoInfo)
pub fn commit_group(self, info: impl UndoInfo)
Push a single action in the current undo scope that undoes/redoes all the captured actions in the transaction.
Note that this will register a group item even if the transaction is empty.