UndoSelect

Trait UndoSelect 

pub trait UndoSelect {
    // Required method
    fn include(&mut self, timestamp: DInstant) -> bool;
}
Selects actions to undo or redo.

Required Methods

fn include(&mut self, timestamp: DInstant) -> bool

Called for each undo or redo action from the last item in the stack and back.

The timestamp is the moment the item was pushed in the undo stack, if this function is called for UndoOp::Redo it will not be more recent than the next action.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl UndoSelect for u32

Source

fn include(&mut self, _: DInstant) -> bool

Implementors