UndoSelector

Trait UndoSelector 

pub trait UndoSelector: Sealed {
    type Select: UndoSelect;

    // Required method
    fn select(self, op: UndoOp) -> Self::Select;
}
Represents a type that can select actions for undo or redo once.

This API is sealed, only core crate can implement it.

See UNDO::undo_select for more details.

Required Associated Types

type Select: UndoSelect

Selection collector.

Required Methods

fn select(self, op: UndoOp) -> Self::Select

Start selecting action for the op.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl UndoSelector for DInstant

Source

type Select = UndoSelectLtEq

Source

fn select(self, op: UndoOp) -> Self::Select

Source

impl UndoSelector for Duration

Source

type Select = UndoSelectInterval

Source

fn select(self, op: UndoOp) -> Self::Select

Source

impl UndoSelector for u32

Source

type Select = u32

Source

fn select(self, op: UndoOp) -> Self::Select

Implementors