WidgetInfoUndoExt

Trait WidgetInfoUndoExt 

pub trait WidgetInfoUndoExt {
    // Required methods
    fn is_undo_scope(&self) -> bool;
    fn undo_scope(&self) -> Option<WidgetInfo>;
}
Undo extension methods for widget info.

Required Methods

fn is_undo_scope(&self) -> bool

Returns true if the widget is an undo scope.

fn undo_scope(&self) -> Option<WidgetInfo>

Gets the first ancestor that is an undo scope.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl WidgetInfoUndoExt for WidgetInfo

Implementors